<?php
/**
*
* ucp.php [Slovenian]
*
* @package language
* @version $Id: $
* @copyright (c) 2011 phpBB Group
* @author 2011-09-30 - pucer, borut, kebabek, KoMar, kramp, lithium, mitja_i, NoBody, nSk, Razor, sollers, Tody, Veron, Janet, JureB
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'ADD_USERS_UCP_EXPLAIN'	=> 'Tukaj lahko dodaš nove uporabnike v skupino. Lahko izbereš, ali postane novo izbrana skupina tudi privzeta skupina za izbrane uporabnike. Vnesi vsakega uporabnika v svojo vrstico.',
	'AVATAR_NOT_ALLOWED'	=> 'Vaš avatar ne more biti prikazan, ker so avatarji bili prepovedani.',
	'AVATAR_TYPE_NOT_ALLOWED'	=> 'Vaš trenutni avatar ne more biti prikazan, ker trenutni tip datoteke je prepovedan.',
	'CLICK_GOTO_FOLDER'	=> '%1$sPojdi v  “%3$s” mapo%2$s',
	'VC_REFRESH'	=> 'Osveži potrditveno kodo',
	'VC_REFRESH_EXPLAIN'	=> 'Če ne moreš prebrati kode, lahko zahtevaš novo z klikom na gumb.',
	'FIELD_INVALID_VALUE'	=> 'Polje “%s” ima neveljaveno vrednost.',
	'FOLDER_NAME_EMPTY'	=> 'Moraš vnesti ime za to mapo.',
	'NOT_ADDED_FRIENDS_BOTS'	=> 'Ne moreš dodati botov med prijatelje.',
	'NOT_ADDED_FOES_BOTS'	=> 'Ne moreš dodati bootov med sovražnike.',
	'REPLY_TO_ALL'	=> 'Odgovori pošiljatelju in vsem prejemnikom',
	'REPORT_PM'	=> 'Prijavi zasebno sporočilo',
	'UNDISCLOSED_RECIPIENT'	=> 'Undisclosed Recipient',
	'NO_AUTH_PASSWORD_REMINDER'	=> 'Nimate pooblastil, da zahtevate novo geslo.',
	'NO_AUTH_READ_HOLD_MESSAGE'	=> 'Nimate pooblastil za branje zasebnih sporočil, ki so na čakanju.',
	'NO_WATCHED_SELECTED'	=> 'Niste izbrali nobene prijavljene teme na forumu.',
	'INVALID_USER_BIRTHDAY'	=> 'Rojstni dan, ki ste ga vnesli, nima veljavnega datuma.',
	'TERMS_OF_USE_CONTENT'	=> 'Z dostopanjem do “%1$s” (nadalje navedeno kot “we”, “us”, “our”, “%1$s”, “%2$s”), uradno potrjujete, da se strinjate z navedenimi pogoji. Če se s katerim od pogojev ne strinjate, vas prosimo, da ne uporabljate oz. dostopate do “%1$s”. Pogoje lahko kadarkoli spremenimo in potrudili se bomo po najboljših močeh, da vas o morebitnih spremembah obvestimo, bilo pa bi dobro, da tudi sami redno pregledujete ta dokument, saj vaša uporaba “%1$s” po spremembah pomeni, da se uradno strinjate z vsemi popravki in nadgradnjami.<br />
	<br />
	Naši forumi tečejo na phpBB platformi za forume (nadalje navedeno kot “oni”, “njim”, “njihov”, “phpBB p”, “www.phpbb.com”, “phpBB skupina”, “phpBB timi”), ki je izdana pod pogoji “<a href="http://www.gnu.org/licenses/gpl.html">General Public License</a>” (nadalje navedeno kot “GPL”) in je na voljo na povezavi <a href="http://www.phpbb.com/">www.phpbb.com</a>. Programska oprema phpBB zgolj omogoča internetne diskusije in GPL jasno omejuje vsebine v okvire tistega, kar dovolimo oz. ne prepovemo. Za nadaljne informacije o phpBB si oglejte povezavo: <a href="http://www.phpbb.com/">http://www.phpbb.com/</a>.<br />
	<br />
	Strinjate se s pogojem, da ne boste objavljali kakršnih koli neprimernih, žaljivih, obrekljivih, vulgarnih, sovražnih, grozečih, seksualnih in podobnih vsebin, ki bi lahko kršile zakone tako vaše države, kjer “%1$s” gostuje, kot tudi mednarodno pravo. Ob kršitvi pravkar omenjenega pogoja vas lahko nemudoma in trajno odstranimo iz sistema in sicer na podlagi obvestila vašega internetnega ponudnika ali če se bo to nam zdelo potrebno. IP naslov vseh objav je zabeležen, kar pripomore k uveljavitvi omenjenih zahtev. Strinjate se, da ima “%1$s” pravico odstraniti, urejati, premakniti ali zapreti katero koli temo in ob času, ki se nam zdi primeren. Kot uporabnik se strinjate, da se vaše objavljene vsebine shrani v arhiv. Vaše informacije ne bodo posredovane naprej brez vašega dovoljenja, vendar pa ne “%1$s” niti phpBB ne prevzemata odgovornosti za poskuse hekerskih vdorov, s katerimi bi lahko prišli do podatkov. ',
	'PRIVACY_POLICY'	=> 'Ta politika natančno opisuje, kako “%1$s”, skupaj s priključenimi podjetji (nadalje navedeno kot "mi", "nas", "naše", “%1$s”, “%2$s”) in phpBB (nadalje navedeno kot "oni", "njih", "njihovo", "phpBB programska oprema", “www.phpbb.com”, “phpBB Group”, “phpBB Timi”), uporabi podatke, zbrane med vašo uporabo (nadalje navedeno kot "vaše informacije”).<br />
	<br />
	Vaši podatki se zbirajo na dva načina. Brskanje po “%1$s” aktivira programsko opremo phpBB, da ustvari nekaj piškotkov (le-ti so majhne tekstovne datoteke) in jih naloži med začasne datoteke spletnega brskalnika vašega računalnika. Prva dva piškotka vsebujeta samo naziv uporabnika (nadalje navedeno kot "uporabniški-id") in naziv anonimne seje (nadalje navedeno kot "sejni-id"), ki vam ju avtomatsko dodeli programska oprema phpBB. Tretji piškotek bo ustvarjen, ko boste prebrskali teme znotraj “%1$s”, uporablja pa se za shranjevanje informacij, katere teme ste že prebrali, in vam s tem pripomore k izboljšanju vaših uporabniških izkušenj.<br />
	<br />
	Med brskanjem po “%1$s” lahko tudi ustvarimo piškotke, ki niso del programske opreme phpBB, in to kljub temu, da so le-ti zunaj področja dokumenta, ki je namenjen pokrivanju zgolj phpBB strani. Drugi način zbiranja podatkov je preko vaših pošiljk nam, ki so lahko omejene na: pošiljanje kot anonimni uporabnik (nadalje navedeno kot "anonimni prispevek"), registracija na “%1$s” (nadalje navedeno kot "vaš račun") in vaši prispevki, ki jih objavite po registraciji in medtem, ko ste prijavljeni (nadalje navedeno kot "vaši prispevki").<br />
	<br />
	Vaš eačun bo vseboval vsaj unikatno identifikacijsko ime (nadalje navedeno kot "uporabniško ime"), osebno geslo za vpisovanje (nadalje navedeno kot "vaše geslo") in veljaven osebni e-mail naslov (nadalje navedeno kot "vaš e-mail"). Vaše podatki o računu na “%1$s” ščitijo zakoni za zaščito podatkov in sicer v državi, ki nas gosti. Vse ostale informacije, ki jih “%1$s” zahteva med procesom registracije, so odmik od naših zahtev po tem, kaj je obvezno in kaj neobvezno. V vseh primerih imate možnost označiti, katere informacije o vas so lahko javno vidne in katere ne. Nadalje imate znotraj vašega računa tudi možnost, da se odločite za ali proti avtomatsko proizvedenim e-mailom programske opreme phpBB.<br />
	<br />
	Vaše geslo je šifrirano in varno. Kakorkoli že, priporočeno je, da ne uporabljate enakega gesla na večih različnih spletnih straneh. Vaše geslo je pot do dostopa do vašega računa na “%1$s”, zato jo res pazljivo varujte. V nobenih okoliščinah vas ne bo nihče, ki je pridružen “%1$s”, phpBB ali kakšni drugi skupini legitimno vprašal po vašem geslu. Če se vam zgodi, da geslo pozabite, lahko uporabite možnost "Pozabil sem svoje geslo", ki jo programska oprema phpBB omogoča. V tem procesu boste naprošeni, da vpišete svoje uporabniško ime in vaš e-mail naslov, programska oprema phpBB pa vam bo priskrbela novo geslo za obnovitev vašega računa.<br />
	',
	'ACCOUNT_ACTIVE'	=> 'Vaš račun je bil aktiviran! Hvala za registracijo!',
	'ACCOUNT_ACTIVE_ADMIN'	=> 'Vaš račun je zdaj aktiviran.',
	'ACCOUNT_ACTIVE_PROFILE'	=> 'Vaš račun je bil uspešno ponovno aktiviran',
	'ACCOUNT_ADDED'	=> 'Hvala za registracijo, vaš račun je bil ustvarjen. Zdaj se lahko prijavite s svojim uporabniškim imenom in geslom.',
	'ACCOUNT_COPPA'	=> 'Vaš račun je bil ustvarjen, toda ni bil odobren, preglejte e-sporočilo za podrobnosti.',
	'ACCOUNT_EMAIL_CHANGED'	=> 'Vaš račun je bil posodobljen. Forum zahteva, da se račun pri menjavi e-poštnega naslova ponovno aktivira. Nov aktivacijski ključ je bil poslan na vaš novi e-poštni naslov.',
	'ACCOUNT_EMAIL_CHANGED_ADMIN'	=> 'Vaš račun je bil posodobljen. Forum zahteva, da se račun ponovno aktivira, to mora opraviti administrator foruma, ki mu je bilo poslano e-sporočilo. Obveščeni boste o nadaljnih ukrepih.',
	'ACCOUNT_INACTIVE'	=> 'Vaš račun je bil ustvarjen. Forum zahteva, da se račun aktivira z aktivacijskim ključem, ki je bil poslan na vaš e-poštni naslov.',
	'ACCOUNT_INACTIVE_ADMIN'	=> 'Vaš račun je bil posodobljen. Forum zahteva, da se račun ponovno aktivira - aktivirati ga mora nekdo iz administratorske skupine. Ko bo račun aktiviran, boste obveščeni.',
	'ACTIVATION_EMAIL_SENT'	=> 'Aktivacijsko e-sporočilo je bila poslana na vaš naslov.',
	'ADD'	=> 'Dodaj',
	'ADD_BCC'	=> 'Dodaj [BCC]',
	'ADD_FOES'	=> 'Dodaj nove sovražnike',
	'ADD_FOES_EXPLAIN'	=> 'Vpišete lahko več uporabniških imen, vsakega v svojo vrstico.',
	'ADD_FOLDER'	=> 'Dodaj mapo',
	'ADD_FRIENDS'	=> 'Dodaj nove prijatelje',
	'ADD_FRIENDS_EXPLAIN'	=> 'Vpišete lahko več uporabniških imen, vsakega v svojo vrstico.',
	'ADD_NEW_RULE'	=> 'Dodaj novo pravilo',
	'ADD_RULE'	=> 'Dodaj pravilo',
	'ADD_TO'	=> 'Dodaj [ZA]',
	'ADMIN_EMAIL'	=> 'Administratorji mi lahko pošiljajo obvestila',
	'AGREE'	=> 'Sprejemam pogoje uporabe',
	'ALLOW_PM'	=> 'Dovoli uporabnikom, da mi pošljejo zasebna sporočila',
	'ALLOW_PM_EXPLAIN'	=> 'Opozorilo! Administatorji in moderatorji vam bodo vedno lahko pošiljali sporočila.',
	'ALREADY_ACTIVATED'	=> 'Vaš račun je bil že aktiviran',
	'ATTACHMENTS_EXPLAIN'	=> 'Tukaj so priponke, ki ste jih pripeli sporočilom na tem forumu',
	'ATTACHMENTS_DELETED'	=> 'Priponke uspešno izbrisane',
	'ATTACHMENT_DELETED'	=> 'Priponka uspešno izbrisana',
	'AVATAR_CATEGORY'	=> 'Kategorija',
	'AVATAR_EXPLAIN'	=> 'Največje dimenzije; širina %1$d pikslov, višina %2$d pikslov, velikost datoteke %3$dkB.',
	'AVATAR_FEATURES_DISABLED'	=> 'Avatarji so trenutno izključeni',
	'AVATAR_GALLERY'	=> 'Lokalna galerija',
	'AVATAR_GENERAL_UPLOAD_ERROR'	=> 'Ne morem naložiti galerije na %s.',
	'AVATAR_PAGE'	=> 'Stran',
	'BACK_TO_DRAFTS'	=> 'Nazaj na shranjene osnutke',
	'BACK_TO_LOGIN'	=> 'Nazaj na prijavni obrazec',
	'BIRTHDAY'	=> 'Rojstni dan',
	'BIRTHDAY_EXPLAIN'	=> 'Ko nastavite leto, se izračuna vaša starost.',
	'BOARD_DATE_FORMAT'	=> 'Moj format datuma',
	'BOARD_DATE_FORMAT_EXPLAIN'	=> 'Sintaksa je enaka kot za PHP funkcijo <a href="http://www.php.net/date">date()</a>.',
	'BOARD_DST'	=> 'Letni čas/<abbr title="Daylight Saving Time">DST</abbr> je vključen',
	'BOARD_LANGUAGE'	=> 'Moj jezik',
	'BOARD_STYLE'	=> 'Moj stil foruma',
	'BOARD_TIMEZONE'	=> 'Moje časovno območje',
	'BOOKMARKS'	=> 'Zaznamki',
	'BOOKMARKS_EXPLAIN'	=> 'Tukaj lahko zaznamujete teme, ki bi jih lahko rabili v prihodnje. Če želite izbrisati zaznamek, označite kvadratek ter kliknite gumb <em>Odstrani označene zaznamke</em>.',
	'BOOKMARKS_DISABLED'	=> 'Zaznamki so na tem forumu onemogočeni',
	'BOOKMARKS_REMOVED'	=> 'Zaznamki so bili uspešno odstranjeni',
	'CANNOT_EDIT_MESSAGE_TIME'	=> 'Ne morete več urejati ali izbrisati tega spročila',
	'CANNOT_MOVE_TO_SAME_FOLDER'	=> 'Sporočila ne morete premakniti v željeno mapo.',
	'CANNOT_RENAME_FOLDER'	=> 'Te mape ne morete preimenovati',
	'CANNOT_REMOVE_FOLDER'	=> 'Te mape ne morete odstraniti',
	'CHANGE_DEFAULT_GROUP'	=> 'Spremeni privzeto skupino',
	'CHANGE_PASSWORD'	=> 'Spremeni geslo',
	'CLICK_RETURN_FOLDER'	=> '%1$sNazaj na mapo “%3$s”%2$s',
	'CONFIRMATION'	=> 'Potrditev registracije',
	'CONFIRM_CHANGES'	=> 'Potrdi spremembe',
	'CONFIRM_EMAIL'	=> 'Potrdi e-poštni naslov',
	'CONFIRM_EMAIL_EXPLAIN'	=> 'To morate navesti samo v primeru, če spreminjate e-poštni naslov.',
	'CONFIRM_EXPLAIN'	=> 'Da bi preprečili samodejne registracije na forum. Koda, ki je morate vnesti, je prikazana spodaj. Če imate kakršnekoli težave zaradi tega, prosimo kontaktirajte %sadministratorja%s.',
	'CONFIRM_PASSWORD'	=> 'Potrdi geslo',
	'CONFIRM_PASSWORD_EXPLAIN'	=> 'Geslo morate potrditi le v primeru, da ste ga zgoraj spremenili',
	'COPPA_BIRTHDAY'	=> 'Da bi nadaljevali z registracijo, nam povejte, kdaj ste rojeni.',
	'COPPA_COMPLIANCE'	=> 'COPPA',
	'COPPA_EXPLAIN'	=> 'S klikom na gumb bo vaš račun ustvarjen, toda ne aktiviran, ker ga mora potrditi vaš starš ali skrbnik. Na vaš e-poštni naslov boste dobili obrazec z vsemi potrebnimi podatki.',
	'CREATE_FOLDER'	=> 'Ustvari mapo…',
	'CURRENT_IMAGE'	=> 'Trenutna slika',
	'CURRENT_PASSWORD'	=> 'Trenutno geslo',
	'CURRENT_PASSWORD_EXPLAIN'	=> 'Če želite spremeniti svoje geslo, uporabniško ime ali e-naslov, morate potrditi trenutno geslo.',
	'CUR_PASSWORD_EMPTY'		=> 'Niste vnesli trenutnega aktivnega gesla.',
	'CUR_PASSWORD_ERROR'	=> 'Trenutno geslo, ki ste ga vnesli, ni pravilno',
	'CUSTOM_DATEFORMAT'	=> 'Po meri…',
	'DEFAULT_ACTION'	=> 'Privzeta akcija',
	'DEFAULT_ACTION_EXPLAIN'	=> 'Ta akcija bo sprožena, če nobena druga ne bo ustrezala',
	'DEFAULT_ADD_SIG'	=> 'Privzeto pripni moj podpis',
	'DEFAULT_BBCODE'	=> 'Privzeto omogoči BBCODE',
	'DEFAULT_NOTIFY'	=> 'Privzeto me obveščaj o odgovorih',
	'DEFAULT_SMILIES'	=> 'Privzeto omogoči smeške',
	'DEFINED_RULES'	=> 'Določena pravila',
	'DELETED_TOPIC'	=> 'Tema je bila odstranjena',
	'DELETE_ATTACHMENT'	=> 'Zbriši priponko',
	'DELETE_ATTACHMENTS'	=> 'Zbriši priponke',
	'DELETE_ATTACHMENT_CONFIRM'	=> 'Ali ste prepričani, da želite zbrisati priponko?',
	'DELETE_ATTACHMENTS_CONFIRM'	=> 'Ali ste prepričani, da želite zbrisati priponke?',
	'DELETE_AVATAR'	=> 'Zbriši sliko',
	'DELETE_COOKIES_CONFIRM'	=> 'Ali želite izbrisati vse piškotke, ki jih je nastavil ta forum?',
	'DELETE_MARKED_PM'	=> 'Izbriši označena sporočila',
	'DELETE_MARKED_PM_CONFIRM'	=> 'Ali ste prepričani, da želite izbrisati vsa označena sporočila?',
	'DELETE_OLDEST_MESSAGES'	=> 'Izbriši najstarejša sporočila',
	'DELETE_MESSAGE'	=> 'Izbriši sporočilo',
	'DELETE_MESSAGE_CONFIRM'	=> 'Ali ste prepričani, da želite izbrisati to zasebno sporočilo?',
	'DELETE_MESSAGES_IN_FOLDER'	=> 'Zbriši vsa sporočila iz premaknjene mape',
	'DELETE_RULE'	=> 'Zbriši pravilo',
	'DELETE_RULE_CONFIRM'	=> 'Ali ste prepričani, da želite zbrisati pravilo?',
	'DEMOTE_SELECTED'	=> 'Odstopi od vodstva skupine',
	'DISABLE_CENSORS'	=> 'Omogoči cenzuro besed',
	'DISPLAY_GALLERY'	=> 'Prikaži galerijo',
	'DOMAIN_NO_MX_RECORD_EMAIL'	=> 'Vpisani e-poštni naslov nima pravilnega MX zapisa',
	'DOWNLOADS'	=> 'Prenosi',
	'DRAFTS_DELETED'	=> 'Vsi izbrani osnutki so bili izbrisani',
	'DRAFTS_EXPLAIN'	=> 'Tukaj lahko urejate svoje osnutke.',
	'DRAFT_UPDATED'	=> 'Osnutek uspešno posodobljen.',
	'EDIT_DRAFT_EXPLAIN'	=> 'Tukaj lahko uredite svoj osnutek. Osnutki ne morejo vsebovati priponk ali anket.',
	'EMAIL_BANNED_EMAIL'	=> 'E-poštni naslov, ki ste ga vnesli, ni dovoljen.',
	'EMAIL_INVALID_EMAIL'	=> 'E-poštni naslov, ki se ga vnesli, ni veljaven.',
	'EMAIL_REMIND'	=> 'Tukaj morate vnesti e-poštni naslov, s katerim ste se registrirali.',
	'EMAIL_TAKEN_EMAIL'	=> 'Vnešeni e-poštni naslov je že v uporabi.',
	'EMPTY_DRAFT'	=> 'Če želite vnesti spremebe, morate vnesti sporočilo',
	'EMPTY_DRAFT_TITLE'	=> 'Vpisati morate naslov osnutka',
	'EXPORT_AS_XML'	=> 'Izvozi v XML',
	'EXPORT_AS_CSV'	=> 'Izvozi v CSV',
	'EXPORT_AS_CSV_EXCEL'	=> 'Izvozi v CSV (Excel)',
	'EXPORT_AS_TXT'	=> 'Izvozi v TXT',
	'EXPORT_AS_MSG'	=> 'Izvozi v MSG',
	'EXPORT_FOLDER'	=> 'Izvozi to mapo',
	'FIELD_REQUIRED'	=> 'Polje “%s” more biti izpoljneno.',
	'FIELD_TOO_SHORT'	=> 'Polje “%1$s” je prekratko, vpisanih mora biti minimalno %2$d znakov.',
	'FIELD_TOO_LONG'	=> 'Polje “%1$s” je predolog, vpisanih je lahko največ %2$d znakov.',
	'FIELD_TOO_SMALL'	=> 'Vrednost “%1$s” je premajhna, najmanjša vrednost tega polja je %2$d .',
	'FIELD_TOO_LARGE'	=> 'Vrdnost polja “%1$s” je prevelika, njavečja dvoljena vrednost je %2$d.',
	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'Polje “%s” vsebuje neveljavne znake, dovoljene so samo številke.',
	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'Polje “%s” vsebuje neveljavne znake, dovoljene so samo številke in črke.',
	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'Polje “%s” vsebuje neveljavne znake, dovoljene so samo številke, črke, presledek in znaki -+_[].',
	'FIELD_INVALID_DATE'	=> 'Polje “%s” vsebuje neveljaven datum.',
	'FOE_MESSAGE'	=> 'Sporočilo od sovražnika',
	'FOES_EXPLAIN'	=> 'Sovražnikova sporočila bodo privzeto ignorirana, sporočilo se ne bo prikazalo v celoti, zasebna sporočila so še vedno dovoljena, ne morete pa ignorirati moderatorja ali administratorja.',
	'FOES_UPDATED'	=> 'Vaša lista sovražnikov je bila uspešno posodobljena',
	'FOLDER_ADDED'	=> 'Mapa je bila uspešno dodana.',
	'FOLDER_MESSAGE_STATUS'	=> '%1$d od %2$d sporočil shranjenih',
	'FOLDER_NAME_EXIST'	=> 'Mapa <strong>%s</strong> že obstaja.',
	'FOLDER_OPTIONS'	=> 'Možnosti mape',
	'FOLDER_RENAMED'	=> 'Mapa uspešno preimenovana.',
	'FOLDER_REMOVED'	=> 'Mapa uspešno izbrisana.',
	'FOLDER_STATUS_MSG'	=> 'Mapa je %1$d%% polna (%2$d od %3$d sporočil shranjenih)',
	'FORWARD_PM'	=> 'Posreduj ZS',
	'FORCE_PASSWORD_EXPLAIN'	=> 'Preden začnete brskati po forumu, si morate zamenjati geslo.',
	'FRIEND_MESSAGE'	=> 'Sporočilo od prijatelja',
	'FRIENDS'	=> 'Prijatelji',
	'FRIENDS_EXPLAIN'	=> 'Prijatelji vam omogočjio hitri dostop do članov z katerimi pogosto komunicirate. Če to forum podpira, lahko vsako objavo od prijatelja označite.',
	'FRIENDS_OFFLINE'	=> 'Ni prisoten',
	'FRIENDS_ONLINE'	=> 'Prisoten',
	'FRIENDS_UPDATED'	=> 'Vaša lista prijateljev je bila uspešno posodobljena',
	'FULL_FOLDER_OPTION_CHANGED'	=> 'Akcija, ki naj se izvede, ko je mapa polna, je bila uspešno spremenjena',
	'FWD_ORIGINAL_MESSAGE'	=> '-------- Originalno sporočilo --------',
	'FWD_SUBJECT'	=> 'Zadeva: %s',
	'FWD_DATE'	=> 'Datum: %s',
	'FWD_FROM'	=> 'Od: %s',
	'FWD_TO'	=> 'Za: %s',
	'GLOBAL_ANNOUNCEMENT'	=> 'Globalno obvestilo',
	'HIDE_ONLINE'	=> 'Skrij moj status prisotnosti',
	'HIDE_ONLINE_EXPLAIN'	=> 'Ta sprememba bo uveljavljena šele ob vašem naslednjem obisku foruma',
	'HOLD_NEW_MESSAGES'	=> 'Ne sprejemaj novih sporočil (nova sporočil bodo zadržana, dokler ne bo zadostne količine prostora)',
	'HOLD_NEW_MESSAGES_SHORT'	=> 'Nova sporočila bodo zadržana',
	'IF_FOLDER_FULL'	=> 'Če je mapa polna',
	'IMPORTANT_NEWS'	=> 'Pomembna obvestila',
	'INVALID_CHARS_USERNAME'	=> 'Uporabinško ime vsebuje nepravilne znake.',
	'INVALID_CHARS_NEW_PASSWORD'	=> 'Geslo ne vsebuje potrebnih znakov.',
	'ITEMS_REQUIRED'	=> 'Polja, označena z * morate obvestno izpolniti.',
	'JOIN_SELECTED'	=> 'Pridruži se izbranim',
	'LANGUAGE'	=> 'Jezik',
	'LINK_REMOTE_AVATAR'	=> 'Povezave izven tega foruma',
	'LINK_REMOTE_AVATAR_EXPLAIN'	=> 'Vnesite povezavo do vašega avatarja',
	'LINK_REMOTE_SIZE'	=> 'Dimenzije avatarja',
	'LINK_REMOTE_SIZE_EXPLAIN'	=> 'Določi višino in širino avatarja. Pustite prazno, če želite, da se določita samodejno.',
	'LOGIN_EXPLAIN_UCP'	=> 'Prosimo, prijavite se, če želite vstopiti v kontrolno ploščo',
	'LOGIN_REDIRECT'	=> 'Uspešno ste se prijavili',
	'LOGOUT_FAILED'	=> 'Niste se uspešeno odjavili iz sistema.',
	'LOGOUT_REDIRECT'	=> 'Uspešno ste se odjavili iz sistema.',
	'MARK_IMPORTANT'	=> 'Označi / odznači kot pomembno',
	'MARKED_MESSAGE'	=> 'Označi sporočilo',
	'MAX_FOLDER_REACHED'	=> 'Maksimalno število dovoljenih uporabnikov za to mapo je doseženo.',
	'MESSAGE_BY_AUTHOR'	=> 'od',
	'MESSAGE_COLOURS'	=> 'Barve sporočila',
	'MESSAGE_DELETED'	=> 'Sporočilo uspešno izbrisano',
	'MESSAGE_HISTORY'	=> 'Zgodovina sporočila',
	'MESSAGE_REMOVED_FROM_OUTBOX'	=> 'To sporočilo je bilo izbrisano - izbrisal ga je avtor pred dostavo.',
	'MESSAGE_SENT_ON'	=> 'dne',
	'MESSAGE_STORED'	=> 'Sporočilo je bilo uspešno poslano',
	'MESSAGE_TO'	=> 'Za',
	'MESSAGES_DELETED'	=> 'Sporočilo uspešno zbrisano',
	'MOVE_DELETED_MESSAGES_TO'	=> 'Premakni sporočila iz odstranjene mape',
	'MOVE_DOWN'	=> 'Pomakni dol',
	'MOVE_MARKED_TO_FOLDER'	=> 'Premakni označene v %s',
	'MOVE_PM_ERROR'	=> 'Napaka pri premikanju sporočil - samo %1d od %2d sporočil je bilo premaknjenih.',
	'MOVE_TO_FOLDER'	=> 'Premakni v mapo',
	'MOVE_UP'	=> 'Pomakni gor',
	
	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Niste vnesli potrjen e-naslov.',
	'NEW_EMAIL_ERROR'	=> 'Vpisana e-naslova se ne ujemata.',
	'NEW_FOLDER_NAME'	=> 'Novo ime mape',
	'NEW_PASSWORD'	=> 'Novo geslo',
	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Niste vnesli potrjeno geslo.',
	'NEW_PASSWORD_ERROR'	=> 'Gesli, ki ste ju vpisali, se ne ujemata.',
	'NOTIFY_METHOD'	=> 'Način obveščanja',
	'NOTIFY_METHOD_BOTH'	=> 'Oboje',
	'NOTIFY_METHOD_EMAIL'	=> 'Samo e-pošta ',
	'NOTIFY_METHOD_EXPLAIN'	=> 'Metoda za obveščanje prek tega foruma.',
	'NOTIFY_METHOD_IM'	=> 'Samo Jabber',
	'NOTIFY_ON_PM'	=> 'Obvesti me o novih zasebnih sporočilih',
	'NOT_ADDED_FRIENDS_ANONYMOUS'	=> 'Ne morete dodati anonimnežev na vašo listo prijateljev.',
	'NOT_ADDED_FRIENDS_FOES'	=> 'Ne morete dodati uporabnika na listo svojih prijateljev, ker je že na listi vaših sovražnikov.',
	'NOT_ADDED_FRIENDS_SELF'	=> 'Sami sebe ne morete dodati kot prijatelja.',
	'NOT_ADDED_FOES_MOD_ADMIN'	=> 'Ne morete dodati moderatorjev ali administratorjev na listo sovražnikov.',
	'NOT_ADDED_FOES_ANONYMOUS'	=> 'Ne morete dodati anonimnežev na listo sovragov',
	'NOT_ADDED_FOES_FRIENDS'	=> 'Ne morete dodati uporabnika na listo svojih sovražnikov, ker je že na listi vaših prijateljev.',
	'NOT_ADDED_FOES_SELF'	=> 'Sami sebe ne morete dodati kot sovražnika.',
	'NOT_AGREE'	=> 'Ne strinjam se s pogoji uporabe',
	'NOT_ENOUGH_SPACE_FOLDER'	=> 'Ciljna mapa “%s” je polna. Zahtevana operacija ni bila izvedena.',
	'NOT_MOVED_MESSAGE'	=> 'Trenutno imate 1 zadržano sporočilo, ker imate poln predal.',
	'NOT_MOVED_MESSAGES'	=> 'Trenutno imate %d zadržanih sporočil, ker imate poln predal.',
	'NO_ACTION_MODE'	=> 'Nobena akcija ni predvidena',
	'NO_AUTHOR'	=> 'Ni definiranega avtorja tega sporočila',
	'NO_AVATAR_CATEGORY'	=> 'Nihče',
	'NO_AUTH_DELETE_MESSAGE'	=> 'Niste avtorizirani, da bi lahko brisali zasebna sporočila',
	'NO_AUTH_EDIT_MESSAGE'	=> 'Niste avtorizirani, da bi urejali zasebno sporočilo.',
	'NO_AUTH_FORWARD_MESSAGE'	=> 'Niste avtorizirani, da bi posredovali zasebno sporočilo.',
	'NO_AUTH_GROUP_MESSAGE'	=> 'Niste avtorizirani, da bi poslali zasebno sporočilo skupini.',
	'NO_AUTH_READ_MESSAGE'	=> 'Niste avtorizirani, da bi brali zasebna sporočila',
	'NO_AUTH_READ_REMOVED_MESSAGE'	=> 'Tega zasebnega sporočila ne morete prebrati, ker ga je avtor umaknil.',
	'NO_AUTH_SEND_MESSAGE'	=> 'Niste avtorizirani, da bi pošiljali zasebna sporočila',
	'NO_AUTH_SIGNATURE'	=> 'Niste avtorizirani, da bi definirali podpis',
	'NO_BCC_RECIPIENT'	=> 'Nihče',
	'NO_BOOKMARKS'	=> 'Nimate zaznamkov',
	'NO_BOOKMARKS_SELECTED'	=> 'Izbrali niste nobenega zanamka.',
	'NO_EMAIL_USER'	=> 'E-poštnega naslova ali uporabniškega imena ni bilo mogoče najti',
	'NO_FOES'	=> 'Noben sovražnik trenutno ni definiran',
	'NO_FRIENDS'	=> 'Noben prijatelj trenutno ni definiran',
	'NO_FRIENDS_OFFLINE'	=> 'Noben prijatelj ni odsoten',
	'NO_FRIENDS_ONLINE'	=> 'Noben prijatelj ni prisoten',
	'NO_GROUP_SELECTED'	=> 'Nobena skupina ni definirana',
	'NO_IMPORTANT_NEWS'	=> 'Ni pomembnih obvestil',
	'NO_MESSAGE'	=> 'Nobenih zasebnih sporočil ni moč najti.',
	'NO_NEW_FOLDER_NAME'	=> 'Navesti morate novo ime za mapo',
	'NO_NEWER_PM'	=> 'Ni novejših sporočil',
	'NO_OLDER_PM'	=> 'Ni starejših sporočil',
	'NO_PASSWORD_SUPPLIED'	=> 'Ne morete se vpisati brez gesla.',
	'NO_RECIPIENT'	=> 'Ni definiranih prejemnikov.',
	'NO_RULES_DEFINED'	=> 'Ni definiranih pravil.',
	'NO_SAVED_DRAFTS'	=> 'Ni shranjenih osnutkov.',
	'NO_TO_RECIPIENT'	=> 'Nihče',
	'NO_WATCHED_FORUMS'	=> 'Ne spremljaš nobenega foruma.',
	'NO_WATCHED_TOPICS'	=> 'Ne spremljaš nobene  teme.',
	'PASS_TYPE_ALPHA_EXPLAIN'	=> 'Geslo mora biti dolgo med %1$d in %2$d znakov ter mora vsebovati tako velike kot male črke in številke.',
	'PASS_TYPE_ANY_EXPLAIN'	=> 'Mora biti med %1$d in %2$d znaki.',
	'PASS_TYPE_CASE_EXPLAIN'	=> 'Geslo mora biti dolgo med %1$d in %2$d znakov ter mora vsebovati tako velike kot male črke',
	'PASS_TYPE_SYMBOL_EXPLAIN'	=> 'Geslo mora biti dolgo med %1$d in %2$d znakov ter mora vsebovati tako velike kot male črke, številke in simbole',
	'PASSWORD'	=> 'Geslo',
	'PASSWORD_ACTIVATED'	=> 'Vaše geslo mora biti potrjeno.',
	'PASSWORD_UPDATED'	=> 'Vaše geslo je bilo uspešno poslano na vaš e-poštni naslov',
	'PERMISSIONS_RESTORED'	=> 'Dovoljenja uspešno ponastavljena',
	'PERMISSIONS_TRANSFERRED'	=> 'Uspešno ste prenesli dovoljenja od <strong>%s</strong> nase. Zdaj lahko brskate po forumu z dovoljenji tega uporabnika. Morebitnih administratorskih dovoljen uporabnika niste prenesli nase. Dovoljenja lahko kadarkoli ponastavite s klikom na "Ponastavi dovoljenja" v glavi foruma.',
	'PM_DISABLED'	=> 'Zasebna sporočila so bila na tem forumu onemogočena',
	'PM_FROM'	=> 'Od',
	'PM_FROM_REMOVED_AUTHOR'	=> 'To sporočilo je poslal uporabnik, ki ni več registriran.',
	'PM_ICON'	=> 'ZS ikona',
	'PM_INBOX'	=> 'Prejeto',
	'PM_NO_USERS'	=> 'Uporabnik, ki ste ga hoteli dodati, ne obstaja.',
	'PM_OUTBOX'	=> 'Odhajajoče',
	'PM_SENTBOX'	=> 'Poslano',
	'PM_SUBJECT'	=> 'Zadeva spročila',
	'PM_TO'	=> 'Poslano k',
	'PM_USERS_REMOVED_NO_PM'	=> 'Nekaterim uporabnikom ni bilo moč poslati sporočila, saj so onemogočili to funkcijo.',
	'POPUP_ON_PM'	=> 'Pojavno okno se pojavi ob novem sporočilu',
	'POST_EDIT_PM'	=> 'Uredi sporočilo',
	'POST_FORWARD_PM'	=> 'Posreduj sporočilo',
	'POST_NEW_PM'	=> 'Ustvari sporočilo',
	'POST_PM_LOCKED'	=> 'Zasebna sporočila so zaklenjena',
	'POST_PM_POST'	=> 'Citiraj objavo',
	'POST_QUOTE_PM'	=> 'Citiraj sporočilo',
	'POST_REPLY_PM'	=> 'Odgovori na sporočilo',
	'PRINT_PM'	=> 'Pogled za tisk',
	'PREFERENCES_UPDATED'	=> 'Vaše nastavitve so bile posodobljene.',
	'PROFILE_INFO_NOTICE'	=> 'Te informacije bodo javno vidne, pazljivo vnašajte podatke. Polja, označena z *, morajo biti nujno izpoljnjena.',
	'PROFILE_UPDATED'	=> 'Vaš profil je bil posodobljen.',
	'RECIPIENT'	=> 'Prejemnik',
	'RECIPIENTS'	=> 'Prejemniki',
	'REGISTRATION'	=> 'Registracija',
	'RELEASE_MESSAGES'	=> '%sSprosti vsa zadržana sporočila%s… sporočila bodo razvrščena v predale, če je v njih zadosti prostora.',
	'REMOVE_ADDRESS'	=> 'Odstrani naslov',
	'REMOVE_SELECTED_BOOKMARKS'	=> 'Odstrani označene zaznamke',
	'REMOVE_SELECTED_BOOKMARKS_CONFIRM'	=> 'Ali ste prepričani, da želite odstraniti zaznamke?',
	'REMOVE_BOOKMARK_MARKED'	=> 'Odstrani označene zaznamke',
	'REMOVE_FOLDER'	=> 'Odstrani mapo',
	'REMOVE_FOLDER_CONFIRM'	=> 'Ali ste prepričani, da želite odstraniti mapo?',
	'RENAME'	=> 'Preimenovanje',
	'RENAME_FOLDER'	=> 'Preimenuj mapo',
	'REPLIED_MESSAGE'	=> 'Odgovori na sporočilo',
	'RESIGN_SELECTED'	=> 'Odstopi od izbranega',
	'RETURN_FOLDER'	=> '%1$sVrni se na prejšno mapo %2$s',
	'RETURN_UCP'	=> '%sVrni se na nadzorno ploščo%s',
	'RULE_ADDED'	=> 'Pravilo uspešno dodano',
	'RULE_ALREADY_DEFINED'	=> 'To pravilo je bilo že definirano',
	'RULE_DELETED'	=> 'Pravilo je bilo uspešno odstranjeno',
	'RULE_NOT_DEFINED'	=> 'Pravilo ni pravilno definirano',
	'RULE_REMOVED_MESSAGE'	=> 'Eno zasebno sporočilo je bilo odstranjeno zaradi filtrov.',
	'RULE_REMOVED_MESSAGES'	=> '%d zasebnih sporočil je bilo odstranjenih zaradi filtrov.',
	'SAME_PASSWORD_ERROR'	=> 'Novo geslo je enako staremu geslu.',
	'SEARCH_YOUR_POSTS'	=> 'Prikaži lastne prispevke',
	'SEND_PASSWORD'	=> 'Pošlji geslo',
	'SENT_AT'	=> 'Poslano ob',
	'SHOW_EMAIL'	=> 'Uporabniki me lahko kontaktirajo prek e-pošte',
	'SIGNATURE_EXPLAIN'	=> 'Podpis je besedilo, ki se samodejno doda na koncu vsake vaše objave. Dolžina besedila je omejena na %d znakov.',
	'SIGNATURE_PREVIEW'	=> 'Izgled vašega podpisa.',
	'SIGNATURE_TOO_LONG'	=> 'Vaš podpis je predolg.',
	'SORT'	=> 'Uredi',
	'SORT_COMMENT'	=> 'Komentar',
	'SORT_DOWNLOADS'	=> 'prenosi',
	'SORT_EXTENSION'	=> 'končnica',
	'SORT_FILENAME'	=> 'ime datoteke',
	'SORT_POST_TIME'	=> 'čas pošiljanja sporočila',
	'SORT_SIZE'	=> 'velikost datoteke',
	'TIMEZONE'	=> 'časovni pas',
	'TO'	=> 'za',
	'TOO_MANY_RECIPIENTS'	=> 'Preveč naslovnikov.',
	'TOO_MANY_REGISTERS'	=> 'Presegli ste največje število poizkusov registracije za to sejo. Prosimo, poskusite znova malo kasneje.',
	'UCP'	=> 'Uporabniška nadzorna plošča',
	'UCP_ACTIVATE'	=> 'Aktiviraj račun',
	'UCP_ADMIN_ACTIVATE'	=> 'Prosimo upoštevajte, da morate vpisati veljaven e-poštni naslov, da bo vaš račun lahko aktiviran. Administrator bo pregledal vašo prijavo in če bo odobrena, boste prejeli potrditveno e-pošto na naslov, ki ste ga navedli.',
	'UCP_AIM'	=> 'AOL Instant Messenger',
	'UCP_ATTACHMENTS'	=> 'Priponke',
	'UCP_COPPA_BEFORE'	=> 'Pred %s',
	'UCP_COPPA_ON_AFTER'	=> 'Na ali po %s',
	'UCP_EMAIL_ACTIVATE'	=> 'Prosimo upoštevajte, da morate vpisati veljaven e-potšni naslov, da bo vaš račun lahko aktiviran. Na naslov, ki ste ga navedli, boste prejeli potrditveno e-pošto, ki vsebuje povezavo za aktivacijo računa.',
	'UCP_ICQ'	=> 'Številka ICQ',
	'UCP_JABBER'	=> 'Naslov Jabber',
	'UCP_MAIN'	=> 'Pregled',
	'UCP_MAIN_ATTACHMENTS'	=> 'Upravljaj s priponkami',
	'UCP_MAIN_BOOKMARKS'	=> 'Upravljaj z zaznamki',
	'UCP_MAIN_DRAFTS'	=> 'Upravljaj s predlogami',
	'UCP_MAIN_FRONT'	=> 'Prva stran',
	'UCP_MAIN_SUBSCRIBED'	=> 'Upravljaj z naročninami',
	'UCP_MSNM'	=> 'MSN Messenger',
	'UCP_NO_ATTACHMENTS'	=> 'Nobena datoteka ni bila poslana.',
	'UCP_PREFS'	=> 'Nastavitve foruma',
	'UCP_PREFS_PERSONAL'	=> 'Uredi splošne nastavitve',
	'UCP_PREFS_POST'	=> 'Uredi osnutek prispevka',
	'UCP_PREFS_VIEW'	=> 'Uredi nastavitve prikaza',
	'UCP_PM'	=> 'Zasebna sporočila',
	'UCP_PM_COMPOSE'	=> 'Pošlji novo zasebno sporočilo',
	'UCP_PM_DRAFTS'	=> 'Uredi osnutke zasebnih sporočil',
	'UCP_PM_OPTIONS'	=> 'Pravila, mape in nastavitve',
	'UCP_PM_POPUP'	=> 'Zasebna sporočila',
	'UCP_PM_POPUP_TITLE'	=> 'Pojavno okno zasebnega sporočila',
	'UCP_PM_UNREAD'	=> 'Neprebrana sporočila',
	'UCP_PM_VIEW'	=> 'Ogled sporočil',
	'UCP_PROFILE'	=> 'Profil',
	'UCP_PROFILE_AVATAR'	=> 'Uredi avatar',
	'UCP_PROFILE_PROFILE_INFO'	=> 'Uredi profil',
	'UCP_PROFILE_REG_DETAILS'	=> 'Uredi nastavitve računa',
	'UCP_PROFILE_SIGNATURE'	=> 'Uredi podpis',
	'UCP_USERGROUPS'	=> 'Skupine',
	'UCP_USERGROUPS_MEMBER'	=> 'Uredi članstvo',
	'UCP_USERGROUPS_MANAGE'	=> 'Uredi skupine',
	'UCP_REGISTER_DISABLE'	=> 'Registracija trenutno ni mogoča.',
	'UCP_REMIND'	=> 'Pošlji geslo',
	'UCP_RESEND'	=> 'Pošlji e-sporočilo za aktivacijo',
	'UCP_WELCOME'	=> 'Dobrodošli v uporabniški nadzorni plošči. Tukaj lahko spremljate, si ogledujete in spreminjate svoj profil, nastavitve, naročene forume in teme. Lahko tudi pošiljate zasebna sporočila drugim uporabnikom (če vam to dovolijo). Prosimo vas, da pred nadaljevanjem preberete vsa obvestila.',
	'UCP_YIM'	=> 'Yahoo Messenger',
	'UCP_ZEBRA'	=> 'Prijatelji &amp; sovražniki',
	'UCP_ZEBRA_FOES'	=> 'Urejaj sovražnike',
	'UCP_ZEBRA_FRIENDS'	=> 'Urejaj prijatelje',
	'UNKNOWN_FOLDER'	=> 'Neznana mapa',
	'UNWATCH_MARKED'	=> 'Ne glej označenih',
	'UPLOAD_AVATAR_FILE'	=> 'Naloži iz svojega računalnika',
	'UPLOAD_AVATAR_URL'	=> 'Naloži iz URLja',
	'UPLOAD_AVATAR_URL_EXPLAIN'	=> 'Vnesite URL naslov, kjer je sličica vaše podobe, ki bo prekopirana na to stran.',
	'USERNAME_ALPHA_ONLY_EXPLAIN'	=> 'Uporabniško ime mora biti dolgo med %1$d in %2$d znakov ter lahko vsebuje le črke in številke.',
	'USERNAME_ALPHA_SPACERS_EXPLAIN'	=> 'Uporabniško ime mora biti dolgo med %1$d in %2$d znakov ter lahko vsebuje le črke in številke, presledek ter znake -+_[].',
	'USERNAME_ASCII_EXPLAIN'	=> 'Uporabniško ime mora biti dolgo med %1$d in %2$d znakov ter lahko vsebuje le ASCII znake brez posebnih simbolov.',
	'USERNAME_LETTER_NUM_EXPLAIN'	=> 'Uporabniško ime mora biti dolgo med %1$d in %2$d znakov ter lahko vsebuje le črke in številke.',
	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'	=> 'Uporabniško ime mora biti dolgo med %1$d in %2$d znakov ter lahko vsebuje le črke in številke, presledek ter znake -+_[].',
	'USERNAME_CHARS_ANY_EXPLAIN'	=> 'Dolžina med %1$d in %2$d znakov.',
	'USERNAME_TAKEN_USERNAME'	=> 'Uporabniško ime, ki ste ga vnesli, je že v uporabi. Prosimo, uporabite drugačno uporabniško ime.',
	'USERNAME_DISALLOWED_USERNAME'	=> 'Uporabniško ime, ki ste ga vnesli, je prepovedano ali pa vsebuje besedo, ki je prepovedana. Prosimo, izberite drugačno uporabniško ime.',
	'USER_NOT_FOUND_OR_INACTIVE'	=> 'Uporabniškega imena, ki ste ga navedli, ni mogoče najti oziroma še ni bilo aktivirano.',
	'VIEW_AVATARS'	=> 'Prikaži avatarje',
	'VIEW_EDIT'	=> 'Glej/Uredi',
	'VIEW_FLASH'	=> 'Prikaži Flash animacije',
	'VIEW_IMAGES'	=> 'Prikaži slike v prispevkih',
	'VIEW_NEXT_HISTORY'	=> 'Naslednje ZS v zgodovini',
	'VIEW_NEXT_PM'	=> 'Naslednje ZS',
	'VIEW_PM'	=> 'Glej sporočilo',
	'VIEW_PM_INFO'	=> 'Podrobnosti sporočila',
	'VIEW_PM_MESSAGE'	=> '1 sporočilo',
	'VIEW_PM_MESSAGES'	=> '%d sporočil',
	'VIEW_PREVIOUS_HISTORY'	=> 'Prejšnje ZS v zgodovini',
	'VIEW_PREVIOUS_PM'	=> 'Prejšnje ZS',
	'VIEW_SIGS'	=> 'Prikaži podpise',
	'VIEW_SMILIES'	=> 'Prikaži smeške kot slike',
	'VIEW_TOPICS_DAYS'	=> 'Prikaži teme iz preteklih dni',
	'VIEW_TOPICS_DIR'	=> 'Prikaži smer urejanja teme',
	'VIEW_TOPICS_KEY'	=> 'Prikaži teme urejene po',
	'VIEW_POSTS_DAYS'	=> 'Prikaži prispevke iz preteklih dni',
	'VIEW_POSTS_DIR'	=> 'Prikaži smer urejanja prispevkov',
	'VIEW_POSTS_KEY'	=> 'Prikaži prispevke, urejene po',
	'WATCHED_EXPLAIN'	=> 'Spodaj je seznam forumov in tem, na katere ste naročeni. Obveščeni boste o novih prispevkih v vsaki od njih. Za odjavo označite forum ali temo in nato kliknite gumb <em>Ne glej označenih</em>.',
	'WATCHED_FORUMS'	=> 'Gledani forumi',
	'WATCHED_TOPICS'	=> 'Gledane teme',
	'WRONG_ACTIVATION'	=> 'Ključ za aktivacijo se ne ujema s pravilnim iz podatkovne baze.',
	'YOUR_DETAILS'	=> 'Vaša aktivnost',
	'YOUR_FOES'	=> 'Vaši sovražniki',
	'YOUR_FOES_EXPLAIN'	=> 'Za odstrantev izberite uporabniško ime in kliknite Pošlji.',
	'YOUR_FRIENDS'	=> 'Vaši prijatelji',
	'YOUR_FRIENDS_EXPLAIN'	=> 'Za odstrantev izberite uporabniško ime in kliknite Pošlji.',
	'YOUR_WARNINGS'	=> 'Vaša stopnja opozorjenosti',

	'PM_ACTION'	=> array(
		'PLACE_INTO_FOLDER'	=> 'Dodaj v mapo',
		'MARK_AS_READ'	=> 'Označi kot prebrano',
		'MARK_AS_IMPORTANT'	=> 'Označi sporočilo',
		'DELETE_MESSAGE'	=> 'Izbriši sporočilo',
	),


	'PM_CHECK'	=> array(
		'SUBJECT'	=> 'Naslov',
		'SENDER'	=> 'Pošiljatelj',
		'MESSAGE'	=> 'Sporočilo',
		'STATUS'	=> 'Status sporočila',
		'TO'	=> 'Poslano',
	),


	'PM_RULE'	=> array(
		'IS_LIKE'	=> 'je kot',
		'IS_NOT_LIKE'	=> 'ni kot',
		'IS'	=> 'je',
		'IS_NOT'	=> 'ni',
		'BEGINS_WITH'	=> 'se začne z/s',
		'ENDS_WITH'	=> 'se konča z/s',
		'IS_FRIEND'	=> 'je prijatelj',
		'IS_FOE'	=> 'je sovražnik',
		'IS_USER'	=> 'je uporabnik',
		'IS_GROUP'	=> 'je v skupini',
		'ANSWERED'	=> 'odgovorjeni',
		'FORWARDED'	=> 'posredovani',
		'TO_GROUP'	=> 'v mojo privzeto skupino',
		'TO_ME'	=> 'zame',
	),

	'GROUPS_EXPLAIN'	=> 'Skupine omogočajo administratorjem učinkovitejši nadzor uporabnikov. Najprej boste dodeljeni specifični skupini, ki bo vaša osnovna skupina. Ta skupina določa, kako boste vidni drugim uporabnikom (npr. barva uporabniškega imena, avatar, rang). Glede na dovoljenja administratorja boste lahko zamenjali osnovno skupino. Lahko boste tudi dodeljeni drugi skupini ali pa vam bo omogočeno menjanje skupin. Nekatere skupine vam lahko dodelijo dodatna dovoljenja za ogled ali vam lahko povečajo vaše pravice v drugih področjih.',
	'GROUP_LEADER'	=> 'Vodje',
	'GROUP_MEMBER'	=> 'Člani',
	'GROUP_PENDING'	=> 'Potencialni člani',
	'GROUP_NONMEMBER'	=> 'Ne-člani',
	'GROUP_DETAILS'	=> 'Podrobnosti skupine',
	'NO_LEADER'	=> 'Skupine brez vodje',
	'NO_MEMBER'	=> 'Skupine brez članov',
	'NO_PENDING'	=> 'Skupine brez potencialnih članov',
	'NO_NONMEMBER'	=> 'Skupine brez ne-članovov',
	'ACTIVATION_EMAIL_SENT_ADMIN'	=> 'E-mail za aktivacijo je bil poslan na administratorjev e-naslov.',
	'CANNOT_MOVE_FROM_SPECIAL'	=> 'Sporočil ni moč premakniti iz mape Odhajajoče.',
	'NO_EDIT_READ_MESSAGE'	=> 'Tega zasebnega sporočila ne morete več urejati, ker je že bilo prebrano.',
));

?>